==> tine20-allinone_2020.08.8.tar.bz2: Tasks/js/Tasks-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ro_RO\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""
 ,""

]
, "Task, Tasks"
: [
  "Task"
 ,"Taskuri"
 ,"Taskuri"

]
, "Percent"
: "Procent"

, "Completed"
: "Completat"

, "Due"
: ""

, "Class"
: ""

, "Description"
: "Descriere"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organizează"

, "Priority"
: "Prioritate"

, "Status, Status"
: [
  "Status"
 ,"Status"
 ,"Status"

]
, "Lead"
: ""

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "Sumar"

, "Due date"
: ""

, "Add Responsible ..."
: ""

, "Notes"
: "Note"

, "Enter description..."
: ""

, "Percentage"
: "Procentaj"

, "Tasks"
: "Taskuri"

, "to do list, to do lists"
: [
  ""
 ,""
 ,""

]
, "to do lists"
: ""

, "Quick Search"
: ""

, "Due Date"
: ""

, "Responsible"
: ""

, "Last Modified Time"
: "Data ultima modificare"

, "Last Modified By"
: "Ultima modificare de"

, "Creation Time"
: ""

, "Created By"
: "Creat de"

, "New Task"
: "Task nou"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  ""
 ,""
 ,""

]
, "Attachments"
: ""

, "Tags"
: "Taguri"

, "Lead name"
: ""

, "Add a task..."
: ""

, "All my tasks"
: ""

, "Default Favorite"
: "Favorite Implicit"

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: "Anulat"

, "In process"
: "În proces"

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: "scăzut"

, "normal"
: "normal"

, "high"
: "înalt"

, "urgent"
: "urgent"

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "%s's personal tasks"
: "%s's  taskuri personale"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: "Ultima modificată de mine"

, "All tasks that I have last modified"
: "Toate contactele pe care le-am modificat "

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "Task"

, "Status"
: "Status"

, "to do list"
: ""

, "Do you really want to delete the selected task?"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "Sumar"

, "Due date"
: ""

, "Priority"
: "Prioritate"

, "Organizer"
: "Organizează"

, "Add Responsible ..."
: ""

, "Notes"
: "Note"

, "Enter description..."
: ""

, "Percentage"
: "Procentaj"

, "Status, Status"
: [
  "Status"
 ,"Status"
 ,"Status"

]
, "Completed"
: "Completat"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  ""
 ,""
 ,""

]
, "Attachments"
: ""

, "Tags"
: "Taguri"

, "Lead name"
: ""

, "Add a task..."
: ""

, "Due Date"
: ""

, "Percent"
: "Procent"

, "Responsible"
: ""

, "Task, Tasks"
: [
  "Task"
 ,"Taskuri"
 ,"Taskuri"

]
, "Tasks"
: "Taskuri"

, "to do list, to do lists"
: [
  ""
 ,""
 ,""

]
, "to do lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: "Data ultima modificare"

, "Last Modified By"
: "Ultima modificare de"

, "Creation Time"
: ""

, "Created By"
: "Creat de"

, "New Task"
: "Task nou"

, "All my tasks"
: ""

, "Default Favorite"
: "Favorite Implicit"

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: "Anulat"

, "In process"
: "În proces"

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: "scăzut"

, "normal"
: "normal"

, "high"
: "înalt"

, "urgent"
: "urgent"

, "%s's personal tasks"
: "%s's  taskuri personale"

, "GENDER_Task"
: ""

, "Due"
: ""

, "Class"
: ""

, "Description"
: "Descriere"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: ""

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: "Ultima modificată de mine"

, "All tasks that I have last modified"
: "Toate contactele pe care le-am modificat "

, "Tasks without responsible"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: ""

, "Task"
: "Task"

, "to do list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
